==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/m365securityandcompliance/kotlin/outputs/GetPrivateEndpointConnectionsForSCCPowershellResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.m365securityandcompliance.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * The Private Endpoint Connection resource.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property name The name of the resource
 * @property privateEndpoint The resource of private end point.
 * @property privateLinkServiceConnectionState A collection of information about the state of the connection between service consumer and provider.
 * @property provisioningState The provisioning state of the private endpoint connection resource.
 * @property systemData Required property for system data
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetPrivateEndpointConnectionsForSCCPowershellResult(
    public val id: String,
    public val name: String,
    public val privateEndpoint: PrivateEndpointResponse? = null,
    public val privateLinkServiceConnectionState: PrivateLinkServiceConnectionStateResponse,
    public val provisioningState: String,
    public val systemData: SystemDataResponse,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.m365securityandcompliance.outputs.GetPrivateEndpointConnectionsForSCCPowershellResult):
            GetPrivateEndpointConnectionsForSCCPowershellResult =
            GetPrivateEndpointConnectionsForSCCPowershellResult(
                id = javaType.id(),
                name = javaType.name(),
                privateEndpoint = javaType.privateEndpoint().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.m365securityandcompliance.kotlin.outputs.PrivateEndpointResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                privateLinkServiceConnectionState = javaType.privateLinkServiceConnectionState().let({ args0 ->
                    com.pulumi.azurenative.m365securityandcompliance.kotlin.outputs.PrivateLinkServiceConnectionStateResponse.Companion.toKotlin(args0)
                }),
                provisioningState = javaType.provisioningState(),
                systemData = javaType.systemData().let({ args0 ->
                    com.pulumi.azurenative.m365securityandcompliance.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
                }),
                type = javaType.type(),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/m365securityandcompliance/kotlin/outputs/GetPrivateEndpointConnectionsForSCCPowershellResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.m365securityandcompliance.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * The Private Endpoint Connection resource.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property name The name of the resource
 * @property privateEndpoint The resource of private end point.
 * @property privateLinkServiceConnectionState A collection of information about the state of the connection between service consumer and provider.
 * @property provisioningState The provisioning state of the private endpoint connection resource.
 * @property systemData Required property for system data
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetPrivateEndpointConnectionsForSCCPowershellResult(
    public val id: String,
    public val name: String,
    public val privateEndpoint: PrivateEndpointResponse? = null,
    public val privateLinkServiceConnectionState: PrivateLinkServiceConnectionStateResponse,
    public val provisioningState: String,
    public val systemData: SystemDataResponse,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.m365securityandcompliance.outputs.GetPrivateEndpointConnectionsForSCCPowershellResult): GetPrivateEndpointConnectionsForSCCPowershellResult =
            GetPrivateEndpointConnectionsForSCCPowershellResult(
                id = javaType.id(),
                name = javaType.name(),
                privateEndpoint = javaType.privateEndpoint().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.m365securityandcompliance.kotlin.outputs.PrivateEndpointResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                privateLinkServiceConnectionState = javaType.privateLinkServiceConnectionState().let({ args0 ->
                    com.pulumi.azurenative.m365securityandcompliance.kotlin.outputs.PrivateLinkServiceConnectionStateResponse.Companion.toKotlin(args0)
                }),
                provisioningState = javaType.provisioningState(),
                systemData = javaType.systemData().let({ args0 ->
                    com.pulumi.azurenative.m365securityandcompliance.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
                }),
                type = javaType.type(),
            )
    }
}
